==> cramr_ui_lib-0.0.17.tar.gz: test/routes/verb_indicative_study_route_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

//TODO: introduce mocking
void main() {
  testWidgets('Test the instantiation based on the cover mode enum',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, 'fr',
            _randomInfinitive, 'translation');
        return model;
      },
      child: VerbIndicativeStudyCoverModeRoute(
          SettingsController(SettingsService(prefs), ThemeMode.dark, prefs),
          key: UniqueKey()),
    ));
    Finder routeFinder =
        find.byKey(const Key('study_scroll_$_randomInfinitive'));
    expect(routeFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-1.0.2.tar.gz: test/routes/verb_indicative_study_route_test.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

//TODO: introduce mocking
void main() {
  testWidgets('Test the instantiation based on the cover mode enum',
      (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await tester.pumpWidget(ChangeNotifierProvider(
      create: (BuildContext context) {
        var model = VerbTestModel();
        model.initialise(_randomIndicative, _randomPronouns, _randomInfinitive,
            'fr', 'translation');
        return model;
      },
      child: VerbIndicativeStudyCoverModeRoute(
          SettingsController(SettingsService(prefs), ThemeMode.dark, prefs),
          key: UniqueKey()),
    ));
    Finder routeFinder =
        find.byKey(const Key('study_scroll_$_randomInfinitive'));
    expect(routeFinder, findsOneWidget);
  });
}
